import { ScalarObject, ScalarType } from 'datapipe-js';
export interface SqlSaveStatus {
    inserted: number;
    updated: number;
    deleted: number;
}
export interface SqlReadQueryInfo {
    fields?: string;
    filter?: string;
    filterParams?: Record<string, ScalarType>;
    skip?: number;
    top?: number;
    orderBy?: string;
    mainTableAlias?: string;
    joins?: [JoinType, string, string][];
}
export interface SqlSaveOptions {
    chunkSize?: number;
    primaryKeys: string[];
    method: 'Merge' | 'Append' | 'BulkInsert';
}
export declare function setBaseUrl(baseUrl: string): void;
export declare function setBearerToken(bearerToken: string): void;
export declare function setUserAccessToken(userAccessToken: string): void;
export declare function authenticate(username: string, password: string): Promise<boolean>;
export declare function sqlDataApi(connectionName: string, config?: {
    baseUrl?: string;
    userAccessToken?: string;
    bearerToken?: string;
}): SqlDataApi;
export declare class SqlDataApi {
    private baseUrl;
    private connectionName;
    private readonly userAccessToken?;
    private readonly bearerToken?;
    private queryInfo;
    private tableName;
    static BaseUrl: string;
    static UserAccessToken: string;
    static BearerToken: string;
    constructor(baseUrl: string, connectionName: string, config: {
        userAccessToken?: string;
        bearerToken?: string;
    });
    filter(filter: string, filterParams?: Record<string, ScalarType>): SqlDataApi;
    select(fields: string): SqlDataApi;
    orderBy(orderBy: string): SqlDataApi;
    top(top: number | string): SqlDataApi;
    innerJoin(tableName: string, joinCondition: string): SqlDataApi;
    leftJoin(tableName: string, joinCondition: string): SqlDataApi;
    rightJoin(tableName: string, joinCondition: string): SqlDataApi;
    join(joinType: JoinType, tableName: string, joinCondition: string): SqlDataApi;
    table(name: string): SqlDataApi;
    runQuery(tableOrViewName?: string, fieldsOrQuery?: string | SqlReadQueryInfo, queryInfoSettings?: SqlReadQueryInfo): Promise<ScalarObject[]>;
    query(tableOrViewName: string, fieldsOrQuery?: string | SqlReadQueryInfo, queryInfoSettings?: SqlReadQueryInfo): Promise<ScalarObject[]>;
    private _query;
    updateData(tableName: string, updateData: Record<string, ScalarType>, filter?: string, filterParams?: Record<string, ScalarType>): Promise<number>;
    deleteFrom(tableName: string, filter?: string, filterParams?: Record<string, ScalarType>): Promise<number>;
    delete(tableName: string, items: Record<string, ScalarType>[]): Promise<boolean>;
    save(tableName: string, items: ScalarObject[], itemsToDeleteOrSaveOptions?: Record<string, unknown>[] | SqlSaveOptions, saveOptions?: SqlSaveOptions): Promise<SqlSaveStatus>;
    saveWithAutoId(tableName: string, item: ScalarObject): Promise<number>;
    sqlExecute(sql: string, params?: ScalarObject): Promise<ScalarObject[] | unknown>;
    private saveData;
    private toPrimitive;
}
export declare function httpRequest<TRequest, TResponse>(method: 'GET' | 'POST' | 'PUT' | 'DELETE', url: string, body?: TRequest, headers?: Record<string, string>): Promise<TResponse>;
export declare function httpGet<TResponse>(url: string, headers?: Record<string, string>): Promise<TResponse>;
export declare function httpGetText(url: string, headers?: Record<string, string>): Promise<string>;
export declare function httpPost<TRequest, TResponse>(url: string, body: TRequest, headers?: Record<string, string>): Promise<TResponse>;
export declare function httpPut<TRequest, TResponse>(url: string, body: TRequest, headers?: Record<string, string>): Promise<TResponse>;
export declare function httpDelete<TRequest, TResponse>(url: string, body: TRequest, headers?: Record<string, string>): Promise<TResponse>;
declare enum JoinType {
    InnerJoin = "InnerJoin",
    LeftJoin = "LeftJoin",
    RightJoin = "RightJoin",
    FullJoin = "FullJoin"
}
export {};
//# sourceMappingURL=sql-data.api.d.ts.map